RCKey enum


ENUM FOR REMOTE CONFIG KEYS (SAFE, NO STRING TYPOS)

Inheritance
Available extensions

Values

showBanner → const RCKey
showBannerCross → const RCKey
showAppOpen → const RCKey
countInterstitial → const RCKey
rewardedEnable → const RCKey
nativeAdEnabled → const RCKey
bannerProvider → const RCKey
appOpenProvider → const RCKey
interstitialProvider → const RCKey
rewardProvider → const RCKey
nativeAdProvider → const RCKey

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
key → String

Available on RCKey, provided by the RCKeyExt extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<RCKey>
A constant List of the values in this enum, in order of their declaration.